@@ -9,9 +9,15 @@ HTML_TEMPLATE_SINGLE_TABLE = '''
     <title>{title}</title>
   </head>
   <body>
-    <h1>{title}</h1>
-    <h3>{subtitle}</h3>
-    {table_html}
+    <div class="container">
+        <div class="row align-items-start">
+            <div class="col">
+                <h1>{title}</h1>
+                <h3>{subtitle}</h3>
+                {table_html}
+            </div>
+        </div>
+    </div>
     <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.9.3/dist/umd/popper.min.js" integrity="sha384-W8fXfP3gkOKtndU4JGtKDvXbO53Wy8SZCQHczT5FMiiqmQfUpWbYdTil/SxwZgAN" crossorigin="anonymous"></script>
     <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.1/dist/js/bootstrap.min.js" integrity="sha384-skAcpIdS7UcVUC05LJ9Dxay8AXcDYfBJqt1CJ85S/CFujBsIzCIv+l9liuYLaMQ/" crossorigin="anonymous"></script>
   </body>
